/*
 * ******************************************************************************************
 *
 * File		: apb_gpio_driver.h
 * Author	: GOWIN
 * Function	: Driver definition of APB GPIO
 *
 * ******************************************************************************************
 */

#ifndef __APB_GPIO_DRIVER_H__
#define __APB_GPIO_DRIVER_H__


#ifdef __cplusplus
extern "C" {
#endif


// Includes ---------------------------------------------------------------------------------
#include "apb_gpio.h"


// Definitions ------------------------------------------------------------------------------

// ------------------------------------------------------------------------------------------
// Functions  : Initializes APB GPIO
// Parameters : cb_event  : APB GPIO ports interrupt event
//				apb_gpiox : Pointer to APB GPIO resources
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio_initialize(APB_GPIO_SignalEvent_t cb_event, APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Uninitialized APB GPIO
// Parameters : apb_gpiox : Pointer to APB GPIO resources
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio_uninitialize(APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Write a value into a pin
// Parameters : pin_num   : A APB GPIO pin
//              val       : The value written into the pin
//				apb_gpiox : Pointer to APB GPIO resources
// ------------------------------------------------------------------------------------------
void apb_gpio_pinwrite(unsigned int pin_num, int val, APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Read a value from a pin
// Parameters : pin_num   : A APB GPIO pin
//				apb_gpiox : Pointer to APB GPIO resources
// Returns    : The value read from the pin
// ------------------------------------------------------------------------------------------
unsigned char apb_gpio_pinread(unsigned int pin_num, APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Write a value into APB GPIO ports
// Parameters : mask      : APB GPIO ports to be used
//              val       : The value written into APB GPIO ports
//				apb_gpiox : Pointer to APB GPIO resources
// ------------------------------------------------------------------------------------------
void apb_gpio_write(unsigned int mask, unsigned int val, APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Read a value from APB GPIO ports
// Parameters : apb_gpiox : Pointer to APB GPIO resources
// Returns    : The value read from APB GPIO ports
// ------------------------------------------------------------------------------------------
unsigned int apb_gpio_read(APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Set APB GPIO direction
// Parameters : mask      : APB GPIO ports to be used
//              dir       : Direction input/output
//				apb_gpiox : Pointer to APB GPIO resources
// ------------------------------------------------------------------------------------------
void apb_gpio_setdir(unsigned int mask, int dir, APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Control command for APB GPIO interrupt, pull, de-bounce
// Parameters : mode      : Interrupt, pull, de-bounce mode or enable/disable
//              mask      : APB GPIO ports to be used
//				clksel    : De-bounce clock source selection (extclk/pclk)
//				scale     : APB GPIO pre-scale base
//				apb_gpiox : Pointer to APB GPIO resources
// Returns    : General return code
// ------------------------------------------------------------------------------------------
int apb_gpio_control(unsigned int mode, unsigned int mask, unsigned int clksel, unsigned int scale, APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : Get APB GPIO configuration status
// Parameters : cfg_info  : Configuration status
//				apb_gpiox : Pointer to APB GPIO resources
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio_get_status(APB_GPIO_CFG_STATUS* cfg_info, APB_GPIO_RESOURCES *apb_gpiox);

// ------------------------------------------------------------------------------------------
// Functions  : APB GPIO interrupt handler
// Parameters : apb_gpiox : Pointer to APB GPIO resources
// ------------------------------------------------------------------------------------------
void apb_gpio_irq_handler(APB_GPIO_RESOURCES *apb_gpiox);


#ifdef __cplusplus
}
#endif


#endif	/* __APB_GPIO_DRIVER_H__ */
