/*
 * ******************************************************************************************
 *
 * File		: apb_gpio_dev.h
 * Author	: GOWIN
 * Function	: Device definition of APB GPIO1
 *
 * ******************************************************************************************
 */

#ifndef __APB_GPIO_DEV_H__
#define __APB_GPIO_DEV_H__


#ifdef __cplusplus
extern "C" {
#endif


// Includes ---------------------------------------------------------------------------------
#include "apb_gpio.h"
#include "apb_gpio_hal.h"


// Definitions ------------------------------------------------------------------------------

/*************************************************************************************
 * An APB GPIO device "APB GPIO1" is defined as a user template.
 * User can define more APB GPIO devices.
 *************************************************************************************/

/*************************************************************************************
 * "X" represents user customized.
 *************************************************************************************/

#define APB_GPIO1_BASE					APB_EXT_BASE/*X*/						// APB GPIO1 address definition
#define APB_GPIO1						((APB_GPIO_RegDef *) APB_GPIO1_BASE )	// APB GPIO1 register definition

#define IRQ_APB_GPIO1_SOURCE			IRQ_GP0_SOURCE/*X*/						// APB GPIO1 interrupt source
#define apb_gpio1_irq_handler			gp0_irq_handler/*X*/					// APB GPIO1 interrupt handler


// APB GPIO1 info
static APB_GPIO_INFO apb_gpio1_info = {0};

// APB GPIO1 resources
static const APB_GPIO_RESOURCES apb_gpio1_resources =
{
	APB_GPIO1,
	IRQ_APB_GPIO1_SOURCE,
	&apb_gpio1_info
};


/*************************************************************************************
 * Functions
 *************************************************************************************/

// ------------------------------------------------------------------------------------------
// Functions  : Initializes APB GPIO1
// Parameters : cb_event  : APB GPIO1 ports interrupt event
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio1_initialize(APB_GPIO_SignalEvent_t cb_event);

// ------------------------------------------------------------------------------------------
// Functions  : Uninitialized APB GPIO1
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio1_uninitialize(void);

// ------------------------------------------------------------------------------------------
// Functions  : Write a value into a pin
// Parameters : pin_num   : A APB GPIO1 pin
//              val       : The value written into the pin
// ------------------------------------------------------------------------------------------
void apb_gpio1_pinwrite(unsigned int pin_num, int val);

// ------------------------------------------------------------------------------------------
// Functions  : Read a value from a pin
// Parameters : pin_num   : A APB GPIO1 pin
// Returns    : The value read from the pin
// ------------------------------------------------------------------------------------------
unsigned char apb_gpio1_pinread(unsigned int pin_num);

// ------------------------------------------------------------------------------------------
// Functions  : Write a value into APB GPIO1 ports
// Parameters : mask      : APB GPIO1 ports to be used
//              val       : The value written into APB GPIO1 ports
// ------------------------------------------------------------------------------------------
void apb_gpio1_write(unsigned int mask, unsigned int val);

// ------------------------------------------------------------------------------------------
// Functions  : Read a value from APB GPIO1 ports
// Returns    : The value read from APB GPIO1 ports
// ------------------------------------------------------------------------------------------
unsigned int apb_gpio1_read(void);

// ------------------------------------------------------------------------------------------
// Functions  : Set APB GPIO1 direction
// Parameters : mask      : APB GPIO1 ports to be used
//              dir       : Direction input/output
// ------------------------------------------------------------------------------------------
void apb_gpio1_setdir(unsigned int mask, int dir);

// ------------------------------------------------------------------------------------------
// Functions  : Control command for APB GPIO1 interrupt, pull, de-bounce
// Parameters : mode      : Interrupt, pull, de-bounce mode or enable/disable
//              mask      : APB GPIO1 ports to be used
//				clksel    : De-bounce clock source selection (extclk/pclk)
//				scale     : APB GPIO1 pre-scale base
// Returns    : General return code
// ------------------------------------------------------------------------------------------
int apb_gpio1_control(unsigned int mode, unsigned int mask, unsigned int clksel, unsigned int scale);

// ------------------------------------------------------------------------------------------
// Functions  : Get APB GPIO1 configuration status
// Parameters : cfg_info  : Configuration status
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio1_get_status(APB_GPIO_CFG_STATUS* cfg_info);

// ------------------------------------------------------------------------------------------
// Functions  : APB GPIO interrupt handler
// ------------------------------------------------------------------------------------------
void apb_gpio1_irq_handler(void);


// As this template, user can define more APB GPIO devices.


#ifdef __cplusplus
}
#endif


#endif	/* __APB_GPIO_DEV_H__ */
