/*
 * ******************************************************************************************
 * File		: config.h
 * Author	: GowinSemicoductor
 * Chip		: AE350_SOC
 * Function	: Configurations
 * ******************************************************************************************
 */

#ifndef __CONFIG_H__
#define __CONFIG_H__

// Definitions -------------------------------------------------------------------------------

// Users can configure the defines in this area
// to match different environment settings


/* -------------------------------- AE350 core configurations -------------------------------- */

// Simulation select
//#define CFG_SIMU		// Do simulation on SID

// Code coverage select
//#define CFG_GCOV		// Do code coverage support

// L1 cache select
#define CFG_CACHE_ENABLE

// Build mode select
// The BUILD_MODE can be specified to BUILD_XIP/BUILD_BURN/BUILD_LOAD only.
/*
 * BUILD_LOAD : ae350-ilm.sag	: debugging in ILM
 *            : ae350-ddr.sag	: debugging in DDR memory
 * BUILD_BURN : ae350-ddr.sag	: booting in Flash memory and running in DDR memory
 * BUILD_XIP  : ae350-xip.sag	: booting and running in Flash memory
 *
 */
#define BUILD_MODE	BUILD_BURN


// The following is predefined settings
// Please do not modify them
#define	BUILD_LOAD	1		// The program is loaded by GDB or eBIOS
#define	BUILD_BURN	2		// The program is burned to the flash, but run in RAM
#define	BUILD_XIP	3		// The program is burned to the flash, and run in flash (xip linker script files must be used)

#if BUILD_MODE == BUILD_LOAD
#define CFG_LOAD
#endif
#if BUILD_MODE == BUILD_BURN
#define CFG_BURN
#endif
#if BUILD_MODE == BUILD_XIP
#define CFG_XIP
#endif


#endif // __CONFIG_H__
