/*
 * ******************************************************************************************
 *
 * File		: apb_gpio_dev.c
 * Author	: GOWIN
 * Function	: Device definition of APB GPIO1
 *
 * ******************************************************************************************
 */

// Includes ---------------------------------------------------------------------------------
#include "apb_gpio_dev.h"
#include "apb_gpio_driver.h"


// Definitions ------------------------------------------------------------------------------

// ------------------------------------------------------------------------------------------
// Functions  : Initializes APB GPIO1
// Parameters : cb_event  : APB GPIO1 ports interrupt event
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio1_initialize(APB_GPIO_SignalEvent_t cb_event)
{
	return apb_gpio_initialize(cb_event, &apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Uninitialized APB GPIO1
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio1_uninitialize(void)
{
	return apb_gpio_uninitialize(&apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Write a value into a pin
// Parameters : pin_num   : A APB GPIO1 pin
//              val       : The value written into the pin
// ------------------------------------------------------------------------------------------
void apb_gpio1_pinwrite(unsigned int pin_num, int val)
{
	apb_gpio_pinwrite(pin_num, val, &apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Read a value from a pin
// Parameters : pin_num   : A APB GPIO1 pin
// Returns    : The value read from the pin
// ------------------------------------------------------------------------------------------
unsigned char apb_gpio1_pinread(unsigned int pin_num)
{
	return apb_gpio_pinread(pin_num, &apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Write a value into APB GPIO1 ports
// Parameters : mask      : APB GPIO1 ports to be used
//              val       : The value written into APB GPIO1 ports
// ------------------------------------------------------------------------------------------
void apb_gpio1_write(unsigned int mask, unsigned int val)
{
	apb_gpio_write(mask, val, &apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Read a value from APB GPIO1 ports
// Returns    : The value read from APB GPIO1 ports
// ------------------------------------------------------------------------------------------
unsigned int apb_gpio1_read(void)
{
	return apb_gpio_read(&apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Set APB GPIO1 direction
// Parameters : mask      : APB GPIO1 ports to be used
//              dir       : Direction input/output
// ------------------------------------------------------------------------------------------
void apb_gpio1_setdir(unsigned int mask, int dir)
{
	apb_gpio_setdir(mask, dir, &apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Control command for APB GPIO1 interrupt, pull, de-bounce
// Parameters : mode      : Interrupt, pull, de-bounce mode or enable/disable
//              mask      : APB GPIO1 ports to be used
//				clksel    : De-bounce clock source selection (extclk/pclk)
//				scale     : APB GPIO1 pre-scale base
// Returns    : General return code
// ------------------------------------------------------------------------------------------
int apb_gpio1_control(unsigned int mode, unsigned int mask, unsigned int clksel, unsigned int scale)
{
	return apb_gpio_control(mode, mask, clksel, scale, &apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : Get APB GPIO1 configuration status
// Parameters : cfg_info  : Configuration status
// Returns    : General return codes
// ------------------------------------------------------------------------------------------
int apb_gpio1_get_status(APB_GPIO_CFG_STATUS* cfg_info)
{
	return apb_gpio_get_status(cfg_info, &apb_gpio1_resources);
}

// ------------------------------------------------------------------------------------------
// Functions  : APB GPIO interrupt handler
// ------------------------------------------------------------------------------------------
void apb_gpio1_irq_handler(void)
{
	apb_gpio_irq_handler(&apb_gpio1_resources);
}
