/*
 * ******************************************************************************************
 *
 * File		: main.c
 * Author	: GOWIN
 * Function	: APB GPIO demo
 *
 * ******************************************************************************************
 */

/*
 ********************************************************************************************
 * This example program shows the usage of the APB GPIO1 interface.
 * It demonstrates the waterfall led.
 *
 * Scenario:
 *
 * After initialized, the demo program will set APB GPIO1 direction to output for waterfall led.
 * The waterfall led is lighted each led.
 *
 * Note: Only APB GPIO1 pin as output, there is no APB GPIO1 pin as input interrupt event, callback
 * function has no event to be handled.
 ********************************************************************************************
* */

// Includes ---------------------------------------------------------------------------------
#include "apb_gpio_dev.h"


// Definitions ------------------------------------------------------------------------------

#define GPIO1_LED_USED_MASK		0x7			// APB GPIO1 pins output as LED
#define NUM_LED					3			// LED number


// Simple delay
// Define "volatile" to prevent optimized.
void simple_delay(volatile unsigned int delay)
{
	for(delay=(OSCFREQ>>15)*delay; delay != 0; delay--);
}

// APB GPIO1 callback event
void gpio1_callback(unsigned int event)
{
	switch (event)
	{
		// Don't have APB GPIO1 pins as interrupt event
		default:
			break;
	}
}

// Application entry function
int main(void)
{
	unsigned char num = 0;
	unsigned int led_pin = 0;	// This led

	// Initializes APB GPIO1
	apb_gpio1_initialize(gpio1_callback);

	// Set APB GPIO1 direction (APB GPIO1 pins as led: output)
	apb_gpio1_setdir(GPIO1_LED_USED_MASK, APB_GPIO_DIR_OUTPUT);

	// Waterfall led
	while(1)
	{
		simple_delay(10000);

		// This led
		led_pin = 0x1 << (num++);

		// Other leds are off
		apb_gpio1_write(~led_pin, 0);

		// This led is on
		apb_gpio1_write(led_pin, 1);

		if(num == NUM_LED)
		{
			num = 0;
		}
	}

	return 0;
}
